/* 
   Ruddy pre-alpha-0.1.0 
   Copyright (C) 2008, The Parrot Foundation.
   $Id: styles.css 1 2008-10-27 09:07:00 igor $
*/
body {
color: white;
background-color: #8c8c8c;
}

#wrapper {
color: black;
background-color: white;
width: 400px;
margin-top: 10px;
margin-right: auto;
margin-bottom: 10px;
margin-left: auto;
}

#header {
  color: black; 
  background-color: white;
  padding: 10px; 
  padding-bottom: 10px;
  padding-top: 10px; 
  border-bottom: 1px solid #8c8c8c; 
  margin-bottom: 20px; 
}

/* ===================================
  El formulario de contacto
=================================== */


#remitente, textarea {
width: 300px;
border: 1px solid #8c8c8c;
margin-bottom: 1em;
}
#text_area { 
  padding-top: 20px ;
  padding-right: 10px; 
  padding-bottom: 20px;
  padding-left: 20px; 
}

textarea { height: 5em; }
textarea:focus
{
  background-color: #d9d9d9;
}
#footer {
  padding: 20px;
  padding-top: 10px; 
  border-top: 1px solid #8c8c8c; 
  margin-top: 20px; 
}

